#!/bin/bash

KERNEL_VERSION="2.6.32-573.3.1.el6.x86_64"

# setup swap if it has not been setup yet
# first, umount asmVG-LVswap if it is mounted as a regular filesystem.
if [ $(mount | grep -c asmVG-LVswap) -eq 1 ]; then umount /swap; fi;

# next, update fstab, if necessary
# this assumes a logical volume named /dev/asmVG/LVswap
if [ $(grep -c 'swap swap' /etc/fstab) -eq 0 ]
then
   echo 'set up swap'
   # remove ext3 entry for LVswap it it still exists
   sed -i -e '/LVswap/d' /etc/fstab
   # make sure LVswap is setup for swap. This erases the first block to remove old on-disk filesystems.
   mkswap /dev/asmVG/LVswap
   # add new entry to fstab
   echo '/dev/asmVG/LVswap swap swap defaults 0 0'>>/etc/fstab
   swapon -av
fi

# Make sure permissions are set correctly; won't have been able to set tomcat group
# on /etc/yum.repos.d/asmcustom.repo until now when the user has been created
chown root:tomcat /etc/yum.repos.d/asmcustom.repo

# Set /etc/yum.repos.d to group tomcat in case the above file gets deleted so that
# tomcat can re-write it
chmod 775 /etc/yum.repos.d
chown root:tomcat /etc/yum.repos.d

# set default ulimit to 4096
#increase system wide max by adding the following line to sysctl.conf
if [ $(grep -c 'file-max' /etc/sysctl.conf) -eq 0 ]; then echo 'fs.file-max = 65536' >> /etc/sysctl.conf; fi;
#then add the following lines to /etc/security/limits.conf
if [ $(grep -c 'hard nofile' /etc/security/limits.conf) -eq 0 ]; then echo '* hard nofile 65536' >> /etc/security/limits.conf; fi;
if [ $(grep -c 'soft nofile' /etc/security/limits.conf) -eq 0 ]; then echo '* soft nofile 4096' >> /etc/security/limits.conf; fi;

# remove default CentOS-Base.repo.  It had enought to bootstrap the installation of this rpm.
# Going forward we will be using ASM.repo which is provided with this rpm and vmwaretools
rm -f /etc/yum.repos.d/CentOS-Base.repo

# this change is required for nfs to work.  otherwise you get Starting NFS mountd: rpc.mountd: svc_tli_create: could not open connection for udp6
sed -i 's/^udp6       tpi_clts      v     inet6    udp     -       -/#udp6       tpi_clts      v     inet6    udp     -       -/' /etc/netconfig
sed -i 's/^tcp6       tpi_cots_ord  v     inet6    tcp     -       -/#tcp6       tpi_cots_ord  v     inet6    tcp     -       -/' /etc/netconfig

sed -i '/^Defaults    requiretty/ s/Defaults    requiretty/#Defaults    requiretty/' /etc/sudoers

# set to run level 3
who -r
currentRunLevel=$(who -r | awk '{print $2}')
if [ "$currentRunLevel" -eq "5" ]; then 
   echo "setting run level to 3 per NIST standards"
   sed -i 's/id:5:initdefault:/id:3:initdefault:/' /etc/inittab
fi

# set default hostname to dellasm
if [ $(grep -c 'HOSTNAME=dellasm' /etc/sysconfig/network) -eq 0 ]
then 
  echo ''>>/etc/sysconfig/network
  echo 'HOSTNAME=dellasm'>>/etc/sysconfig/network
  hostname dellasm
fi

names="dellasm puppet asm-core-api asm-deployer-api asm-graphite-api asm-nagios-api asm-puppetdb-api asm-razor-api asm-secrets-api"
for name in $names; do
    if [ $(grep -c $name /etc/hosts) -eq 0 ]; then
        echo "127.0.0.1 $name" >> /etc/hosts
    fi
done

echo 'chkconfig --add configureVM'
/sbin/chkconfig --add configureVM

# ASM Appliance initially had /etc/grub.conf as a plain file, but it should be a
# symlink to /boot/grub/grub.conf.  Otherwise kernel updates do not update the
# boot order

if [ ! -h /etc/grub.conf ]; then
  pushd /etc
  mv grub.conf grub.conf.save
  ln -s ../boot/grub/grub.conf
  popd
fi

## Test to see if the new kernel version is used
if ! grep -q ${KERNEL_VERSION} /etc/grub.conf; then
  cp /opt/Dell/ASM/grub.conf /boot/grub/grub.conf
fi
